@@ -36,20 +36,9 @@ G_BEGIN_DECLS
 
 /* Animation support */
 
-/**
- * GdkPixbufAnimation:
- *
- * An opaque struct representing an animation.
- */
 typedef struct _GdkPixbufAnimation GdkPixbufAnimation;
 
 
-/**
- * GdkPixbufAnimationIter:
- *
- * An opaque struct representing an iterator which points to a
- * certain position in an animation.
- */
 typedef struct _GdkPixbufAnimationIter GdkPixbufAnimationIter;
 
 #define GDK_TYPE_PIXBUF_ANIMATION              (gdk_pixbuf_animation_get_type ())
@@ -89,13 +78,10 @@ GDK_PIXBUF_AVAILABLE_IN_2_28
 GdkPixbufAnimation *gdk_pixbuf_animation_new_from_resource(const char        *resource_path,
                                                           GError            **error);
 
-#ifndef GDK_PIXBUF_DISABLE_DEPRECATED
-
 GDK_PIXBUF_DEPRECATED_IN_2_0_FOR(g_object_ref)
 GdkPixbufAnimation *gdk_pixbuf_animation_ref             (GdkPixbufAnimation *animation);
 GDK_PIXBUF_DEPRECATED_IN_2_0_FOR(g_object_unref)
 void                gdk_pixbuf_animation_unref           (GdkPixbufAnimation *animation);
-#endif
 
 GDK_PIXBUF_AVAILABLE_IN_ALL
 int                 gdk_pixbuf_animation_get_width       (GdkPixbufAnimation *animation);
@@ -161,17 +147,16 @@ struct _GdkPixbufAnimationClass {
 
         /*< public >*/
 
-        gboolean                (*is_static_image)  (GdkPixbufAnimation *anim);
+        gboolean                (*is_static_image)  (GdkPixbufAnimation *animation);
 
-        GdkPixbuf*              (*get_static_image) (GdkPixbufAnimation *anim);
-        
-        void                    (*get_size) (GdkPixbufAnimation *anim,
+        GdkPixbuf*              (*get_static_image) (GdkPixbufAnimation *animation);
+
+        void                    (*get_size) (GdkPixbufAnimation *animation,
                                              int                 *width,
                                              int                 *height);
-        
-        GdkPixbufAnimationIter* (*get_iter) (GdkPixbufAnimation *anim,
-                                             const GTimeVal     *start_time);
 
+        GdkPixbufAnimationIter* (*get_iter) (GdkPixbufAnimation *animation,
+                                             const GTimeVal     *start_time);
 };
 G_GNUC_END_IGNORE_DEPRECATIONS
 
@@ -219,7 +204,11 @@ struct _GdkPixbufAnimationIterClass {
                                         const GTimeVal         *current_time);
 };
 G_GNUC_END_IGNORE_DEPRECATIONS
-      
+
+#define GDK_TYPE_PIXBUF_NON_ANIM              (gdk_pixbuf_non_anim_get_type ())
+#define GDK_PIXBUF_NON_ANIM(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), GDK_TYPE_PIXBUF_NON_ANIM, GdkPixbufNonAnim))
+#define GDK_IS_PIXBUF_NON_ANIM(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), GDK_TYPE_PIXBUF_NON_ANIM))
+
 
 GDK_PIXBUF_AVAILABLE_IN_ALL
 GType               gdk_pixbuf_non_anim_get_type (void) G_GNUC_CONST;
