@@ -36,75 +36,6 @@
 
 G_BEGIN_DECLS
 
-/**
- * SECTION:gdk-pixbuf
- * @Short_description: Information that describes an image.
- * @Title: The GdkPixbuf Structure
- * 
- * The #GdkPixbuf structure contains
- * information that describes an image in memory.
- * 
- * ## Image Data ## {#image-data}
- *
- * Image data in a pixbuf is stored in memory in uncompressed,
- * packed format.  Rows in the image are stored top to bottom, and
- * in each row pixels are stored from left to right.  There may be
- * padding at the end of a row.  The "rowstride" value of a pixbuf,
- * as returned by gdk_pixbuf_get_rowstride(), indicates the number
- * of bytes between rows.
- * 
- * ## put_pixel() Example ## {#put-pixel}
- * 
- * The following code illustrates a simple put_pixel()
- * function for RGB pixbufs with 8 bits per channel with an alpha
- * channel.  It is not included in the gdk-pixbuf library for
- * performance reasons; rather than making several function calls
- * for each pixel, your own code can take shortcuts.
- * 
- * |[<!-- language="C" -->
- * static void
- * put_pixel (GdkPixbuf *pixbuf, int x, int y, guchar red, guchar green, guchar blue, guchar alpha)
- * {
- *   int width, height, rowstride, n_channels;
- *   guchar *pixels, *p;
- * 
- *   n_channels = gdk_pixbuf_get_n_channels (pixbuf);
- * 
- *   g_assert (gdk_pixbuf_get_colorspace (pixbuf) == GDK_COLORSPACE_RGB);
- *   g_assert (gdk_pixbuf_get_bits_per_sample (pixbuf) == 8);
- *   g_assert (gdk_pixbuf_get_has_alpha (pixbuf));
- *   g_assert (n_channels == 4);
- * 
- *   width = gdk_pixbuf_get_width (pixbuf);
- *   height = gdk_pixbuf_get_height (pixbuf);
- * 
- *   g_assert (x >= 0 && x < width);
- *   g_assert (y >= 0 && y < height);
- * 
- *   rowstride = gdk_pixbuf_get_rowstride (pixbuf);
- *   pixels = gdk_pixbuf_get_pixels (pixbuf);
- * 
- *   p = pixels + y * rowstride + x * n_channels;
- *   p[0] = red;
- *   p[1] = green;
- *   p[2] = blue;
- *   p[3] = alpha;
- * }
- * ]|
- * 
- * This function will not work for pixbufs with images that are
- * other than 8 bits per sample or channel, but it will work for
- * most of the pixbufs that GTK+ uses.
- * 
- * If you are doing memcpy() of raw pixbuf data, note that the last row
- * in the pixbuf may not be as wide as the full rowstride, but rather
- * just as wide as the pixel data needs to be. That is, it is unsafe to
- * do `memcpy (dest, pixels, rowstride * height)` to copy a whole pixbuf.
- * Use gdk_pixbuf_copy() instead, or compute the width in bytes of the
- * last row as `width * ((n_channels * bits_per_sample + 7) / 8)`.
- */
-
-
 /**
  * GdkPixbufAlphaMode:
  * @GDK_PIXBUF_ALPHA_BILEVEL: A bilevel clipping mask (black and white)
@@ -113,15 +44,23 @@ G_BEGIN_DECLS
  *  considered fully opaque.
  * @GDK_PIXBUF_ALPHA_FULL: For now falls back to #GDK_PIXBUF_ALPHA_BILEVEL.
  *  In the future it will do full alpha compositing.
- * 
- * These values can be passed to
- * gdk_pixbuf_xlib_render_to_drawable_alpha() to control how the alpha
- * channel of an image should be handled.  This function can create a
- * bilevel clipping mask (black and white) and use it while painting
- * the image.  In the future, when the X Window System gets an alpha
- * channel extension, it will be possible to do full alpha
- * compositing onto arbitrary drawables.  For now both cases fall
- * back to a bilevel clipping mask.
+ *
+ * Control the alpha channel for drawables.
+ *
+ * These values can be passed to gdk_pixbuf_xlib_render_to_drawable_alpha()
+ * in gdk-pixbuf-xlib to control how the alpha channel of an image should
+ * be handled.
+ *
+ * This function can create a bilevel clipping mask (black and white) and use
+ * it while painting the image.
+ *
+ * In the future, when the X Window System gets an alpha channel extension,
+ * it will be possible to do full alpha compositing onto arbitrary drawables.
+ * For now both cases fall back to a bilevel clipping mask.
+ *
+ * Deprecated: 2.42: There is no user of GdkPixbufAlphaMode in GdkPixbuf,
+ *   and the Xlib utility functions have been split out to their own
+ *   library, gdk-pixbuf-xlib
  */
 typedef enum
 {
@@ -134,7 +73,9 @@ typedef enum
  * @GDK_COLORSPACE_RGB: Indicates a red/green/blue additive color space.
  * 
  * This enumeration defines the color spaces that are supported by
- * the gdk-pixbuf library.  Currently only RGB is supported.
+ * the gdk-pixbuf library.
+ *
+ * Currently only RGB is supported.
  */
 /* Note that these values are encoded in inline pixbufs
  * as ints, so don't reorder them
@@ -145,15 +86,6 @@ typedef enum {
 
 /* All of these are opaque structures */
 
-/**
- * GdkPixbuf:
- * 
- * This is the main structure in the gdk-pixbuf library.  It is
- * used to represent images.  It contains information about the
- * image's pixel data, its color space, bits per sample, width and
- * height, and the rowstride (the number of bytes between the start of
- * one row and the start of the next). 
- */
 typedef struct _GdkPixbuf GdkPixbuf;
 
 #define GDK_TYPE_PIXBUF              (gdk_pixbuf_get_type ())
@@ -168,20 +100,23 @@ typedef struct _GdkPixbuf GdkPixbuf;
  * @data: (closure): User closure data.
  * 
  * A function of this type is responsible for freeing the pixel array
- * of a pixbuf.  The gdk_pixbuf_new_from_data() function lets you
- * pass in a pre-allocated pixel array so that a pixbuf can be
- * created from it; in this case you will need to pass in a function
- * of #GdkPixbufDestroyNotify so that the pixel data can be freed
- * when the pixbuf is finalized.
+ * of a pixbuf.
+ *
+ * The gdk_pixbuf_new_from_data() function lets you pass in a pre-allocated
+ * pixel array so that a pixbuf can be created from it; in this case you
+ * will need to pass in a function of type `GdkPixbufDestroyNotify` so that
+ * the pixel data can be freed when the pixbuf is finalized.
  */
 typedef void (* GdkPixbufDestroyNotify) (guchar *pixels, gpointer data);
 
 /**
  * GDK_PIXBUF_ERROR:
  * 
- * Error domain used for pixbuf operations. Indicates that the error code
- * will be in the #GdkPixbufError enumeration. See #GError for
- * information on error domains and error codes.
+ * Error domain used for pixbuf operations.
+ *
+ * Indicates that the error code will be in the `GdkPixbufError` enumeration.
+ *
+ * See the `GError` for information on error domains and error codes.
  */
 #define GDK_PIXBUF_ERROR gdk_pixbuf_error_quark ()
 
@@ -196,9 +131,10 @@ typedef void (* GdkPixbufDestroyNotify) (guchar *pixels, gpointer data);
  * @GDK_PIXBUF_ERROR_FAILED: Generic failure code, something went wrong.
  * @GDK_PIXBUF_ERROR_INCOMPLETE_ANIMATION: Only part of the animation was loaded.
  * 
- * An error code in the #GDK_PIXBUF_ERROR domain. Many gdk-pixbuf
- * operations can cause errors in this domain, or in the #G_FILE_ERROR
- * domain.
+ * An error code in the `GDK_PIXBUF_ERROR` domain.
+ *
+ * Many gdk-pixbuf operations can cause errors in this domain, or in
+ * the `G_FILE_ERROR` domain.
  */
 typedef enum {
         /* image data hosed */
@@ -225,12 +161,10 @@ GType gdk_pixbuf_get_type (void) G_GNUC_CONST;
 
 /* Reference counting */
 
-#ifndef GDK_PIXBUF_DISABLE_DEPRECATED
 GDK_PIXBUF_DEPRECATED_IN_2_0_FOR(g_object_ref)
 GdkPixbuf *gdk_pixbuf_ref      (GdkPixbuf *pixbuf);
 GDK_PIXBUF_DEPRECATED_IN_2_0_FOR(g_object_unref)
 void       gdk_pixbuf_unref    (GdkPixbuf *pixbuf);
-#endif
 
 /* GdkPixbuf accessors */
 
@@ -270,6 +204,13 @@ GDK_PIXBUF_AVAILABLE_IN_ALL
 GdkPixbuf *gdk_pixbuf_new (GdkColorspace colorspace, gboolean has_alpha, int bits_per_sample,
 			   int width, int height);
 
+GDK_PIXBUF_AVAILABLE_IN_2_36
+gint gdk_pixbuf_calculate_rowstride (GdkColorspace colorspace,
+				     gboolean      has_alpha,
+				     int           bits_per_sample,
+				     int           width,
+				     int           height);
+
 /* Copy a pixbuf */
 GDK_PIXBUF_AVAILABLE_IN_ALL
 GdkPixbuf *gdk_pixbuf_copy (const GdkPixbuf *pixbuf);
@@ -347,17 +288,14 @@ GdkPixbuf *gdk_pixbuf_new_from_bytes (GBytes *data,
 				      int width, int height,
 				      int rowstride);
 
-GDK_PIXBUF_AVAILABLE_IN_ALL
+GDK_PIXBUF_DEPRECATED_IN_2_44
 GdkPixbuf *gdk_pixbuf_new_from_xpm_data (const char **data);
 
-#ifndef GDK_PIXBUF_DISABLE_DEPRECATED
 GDK_PIXBUF_DEPRECATED_IN_2_32
 GdkPixbuf* gdk_pixbuf_new_from_inline	(gint          data_length,
 					 const guint8 *data,
 					 gboolean      copy_pixels,
 					 GError      **error);
-#endif
-
 /* Mutations */
 GDK_PIXBUF_AVAILABLE_IN_ALL
 void       gdk_pixbuf_fill              (GdkPixbuf    *pixbuf,
@@ -407,15 +345,18 @@ gboolean gdk_pixbuf_savev_utf8     (GdkPixbuf  *pixbuf,
  * @error: (out): A location to return an error.
  * @data: (closure): user data passed to gdk_pixbuf_save_to_callback(). 
  * 
- * Specifies the type of the function passed to
- * gdk_pixbuf_save_to_callback().  It is called once for each block of
- * bytes that is "written" by gdk_pixbuf_save_to_callback().  If
- * successful it should return %TRUE.  If an error occurs it should set
- * @error and return %FALSE, in which case gdk_pixbuf_save_to_callback()
+ * Save functions used by [method@GdkPixbuf.Pixbuf.save_to_callback].
+ *
+ * This function is called once for each block of bytes that is "written"
+ * by `gdk_pixbuf_save_to_callback()`.
+ *
+ * If successful it should return `TRUE`; if an error occurs it should set
+ * `error` and return `FALSE`, in which case `gdk_pixbuf_save_to_callback()`
  * will fail with the same error.
+ *
+ * Returns: `TRUE` if successful, `FALSE` otherwise
  * 
  * Since: 2.4
- * Returns: %TRUE if successful, %FALSE (with @error set) if failed.
  */
 
 typedef gboolean (*GdkPixbufSaveFunc)   (const gchar *buf,
