@@ -715,4 +715,14 @@
 #endif
 #endif /* __GTK_DOC_IGNORE__ */
 
+#ifndef __GTK_DOC_IGNORE__
+#if GDK_PIXBUF_VERSION_MIN_REQUIRED >= GDK_PIXBUF_VERSION_2_44
+#define GDK_PIXBUF_DEPRECATED_IN_2_44 G_DEPRECATED _GDK_PIXBUF_EXTERN
+#define GDK_PIXBUF_DEPRECATED_IN_2_44_FOR(f) G_DEPRECATED_FOR(f) _GDK_PIXBUF_EXTERN
+#else
+#define GDK_PIXBUF_DEPRECATED_IN_2_44 _GDK_PIXBUF_EXTERN
+#define GDK_PIXBUF_DEPRECATED_IN_2_44_FOR(f) _GDK_PIXBUF_EXTERN
+#endif
+#endif /* __GTK_DOC_IGNORE__ */
+
 #endif /* GDK_PIXBUF_MACROS_H */
